﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2016 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using HeuristicLab.Common;

namespace HeuristicLab.Core {
  public class PersistenceContentManager : ContentManager {
    public PersistenceContentManager() : base() { }

    protected override IStorableContent LoadContent(string filename) {
      #region backwards compatibility 
      // try to deserialize with new serializer first
      var serializer = new HeuristicLab.Persistence.ProtoBufSerializer();
      IStorableContent content;
      try {
        content = (IStorableContent)serializer.Deserialize(filename);
        return content;
      } catch (Exception e) { }
      return HeuristicLab.Persistence.Default.Xml.XmlParser.Deserialize<IStorableContent>(filename);
      #endregion
    }

    protected override void SaveContent(IStorableContent content, string filename) {
      // XmlGenerator.Serialize(content, filename, compressed ? CompressionLevel.Optimal : CompressionLevel.NoCompression);

      var serializer = new HeuristicLab.Persistence.ProtoBufSerializer();
      serializer.Serialize(content, filename);
    }
  }
}
